@@ -27,20 +27,17 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#ifndef ATTRIBUTE_UNUSED
-#define ATTRIBUTE_UNUSED __attribute__ ((__unused__))
-#endif
 /*
  *  version.h
  */
 
 #define SND_LIB_MAJOR		0
 #define SND_LIB_MINOR		5
-#define SND_LIB_SUBMINOR	10
+#define SND_LIB_SUBMINOR	1
 #define SND_LIB_VERSION		((SND_LIB_MAJOR<<16)|\
 				 (SND_LIB_MINOR<<8)|\
 				  SND_LIB_SUBMINOR)
-#define SND_LIB_VERSION_STR	"0.5.10b"
+#define SND_LIB_VERSION_STR	"0.5.1"
 
 /* OBSOLETE DEFINES WHICH WON'T BE IN 0.3.0 FINAL!!! */
 #define SOUNDLIB_VERSION_MAJOR		SND_LIB_MAJOR
@@ -74,9 +71,7 @@ const char *snd_strerror( int errnum );
 typedef struct snd_ctl_callbacks {
 	void *private_data;	/* should be used by an application */
 	void (*rebuild) (void *private_data);
-	void (*xswitch) (void *private_data, int cmd,
-			 int iface, int device, int channel,
-			 snd_switch_list_item_t *item);
+	void (*xswitch) (void *private_data, int cmd, int iface, snd_switch_list_item_t *item);
 	void *reserved[29];	/* reserved for the future use - must be NULL!!! */
 } snd_ctl_callbacks_t;
 
@@ -112,8 +107,26 @@ int snd_ctl_hwdep_info(snd_ctl_t *handle, int dev, snd_hwdep_info_t * info);
 int snd_ctl_pcm_info(snd_ctl_t *handle, int dev, snd_pcm_info_t * info);
 int snd_ctl_pcm_channel_info(snd_ctl_t *handle, int dev, int channel, int subdev, snd_pcm_channel_info_t * info);
 int snd_ctl_pcm_channel_prefer_subdevice(snd_ctl_t *handle, int dev, int channel, int subdev);
+int snd_ctl_pcm_channel_switch_list(snd_ctl_t *handle, int dev, int channel, snd_switch_list_t * list);
+int snd_ctl_pcm_playback_switch_list(snd_ctl_t *handle, int dev, snd_switch_list_t * list);
+int snd_ctl_pcm_capture_switch_list(snd_ctl_t *handle, int dev, snd_switch_list_t * list);
+int snd_ctl_pcm_channel_switch_read(snd_ctl_t *handle, int dev, int channel, snd_switch_t * sw);
+int snd_ctl_pcm_playback_switch_read(snd_ctl_t *handle, int dev, snd_switch_t * sw);
+int snd_ctl_pcm_capture_switch_read(snd_ctl_t *handle, int dev, snd_switch_t * sw);
+int snd_ctl_pcm_channel_switch_write(snd_ctl_t *handle, int dev, int channel, snd_switch_t * sw);
+int snd_ctl_pcm_playback_switch_write(snd_ctl_t *handle, int dev, snd_switch_t * sw);
+int snd_ctl_pcm_capture_switch_write(snd_ctl_t *handle, int dev, snd_switch_t * sw);
 int snd_ctl_mixer_info(snd_ctl_t *handle, int dev, snd_mixer_info_t * info);
+int snd_ctl_mixer_switch_list(snd_ctl_t *handle, int dev, snd_switch_list_t *list);
+int snd_ctl_mixer_switch_read(snd_ctl_t *handle, int dev, snd_switch_t * sw);
+int snd_ctl_mixer_switch_write(snd_ctl_t *handle, int dev, snd_switch_t * sw);
 int snd_ctl_rawmidi_info(snd_ctl_t *handle, int dev, snd_rawmidi_info_t * info);
+int snd_ctl_rawmidi_output_switch_list(snd_ctl_t *handle, int dev, snd_switch_list_t *list);
+int snd_ctl_rawmidi_output_switch_read(snd_ctl_t *handle, int dev, snd_switch_t * sw);
+int snd_ctl_rawmidi_output_switch_write(snd_ctl_t *handle, int dev, snd_switch_t * sw);
+int snd_ctl_rawmidi_input_switch_list(snd_ctl_t *handle, int dev, snd_switch_list_t *list);
+int snd_ctl_rawmidi_input_switch_read(snd_ctl_t *handle, int dev, snd_switch_t * sw);
+int snd_ctl_rawmidi_input_switch_write(snd_ctl_t *handle, int dev, snd_switch_t * sw);
 int snd_ctl_read(snd_ctl_t *handle, snd_ctl_callbacks_t * callbacks);
 
 #ifdef __cplusplus
@@ -178,7 +191,7 @@ void snd_mixer_sort_eid_name_index(snd_mixer_eid_t *list, int count);
 void snd_mixer_sort_eid_table(snd_mixer_eid_t *list, int count, snd_mixer_weight_entry_t *table);
 void snd_mixer_sort_gid_name_index(snd_mixer_gid_t *list, int count);
 void snd_mixer_sort_gid_table(snd_mixer_gid_t *list, int count, snd_mixer_weight_entry_t *table);
-extern snd_mixer_weight_entry_t *snd_mixer_default_weights;
+snd_mixer_weight_entry_t *snd_mixer_default_weights;
 
 #ifdef __cplusplus
 }
@@ -228,8 +241,6 @@ int snd_pcm_playback_pause(snd_pcm_t *handle, int enable);
 ssize_t snd_pcm_transfer_size(snd_pcm_t *handle, int channel);
 ssize_t snd_pcm_write(snd_pcm_t *handle, const void *buffer, size_t size);
 ssize_t snd_pcm_read(snd_pcm_t *handle, void *buffer, size_t size);
-ssize_t snd_pcm_writev(snd_pcm_t *pcm, const struct iovec *vector, int count);
-ssize_t snd_pcm_readv(snd_pcm_t *pcm, const struct iovec *vector, int count);
 int snd_pcm_mmap(snd_pcm_t *handle, int channel, snd_pcm_mmap_control_t **control, void **buffer);
 int snd_pcm_munmap(snd_pcm_t *handle, int channel);
 
@@ -240,11 +251,9 @@ int snd_pcm_format_unsigned(int format);
 int snd_pcm_format_linear(int format);
 int snd_pcm_format_little_endian(int format);
 int snd_pcm_format_big_endian(int format);
-int snd_pcm_format_width(int format);			/* in bits */
-int snd_pcm_format_physical_width(int format);		/* in bits */
+int snd_pcm_format_width(int format);		/* in bits */
 int snd_pcm_build_linear_format(int width, int unsignd, int big_endian);
 ssize_t snd_pcm_format_size(int format, size_t samples);
-unsigned char snd_pcm_format_silence(int format);
 const char *snd_pcm_get_format_name(int format);
 
 #ifdef __cplusplus
@@ -297,7 +306,7 @@ int snd_pcm_plugin_params(snd_pcm_t *handle, snd_pcm_channel_params_t *params);
 int snd_pcm_plugin_setup(snd_pcm_t *handle, snd_pcm_channel_setup_t *setup);
 int snd_pcm_plugin_status(snd_pcm_t *handle, snd_pcm_channel_status_t *status);
 int snd_pcm_plugin_prepare(snd_pcm_t *handle, int channel);
-int snd_pcm_plugin_playback_drain(snd_pcm_t *handle);
+int snd_pcm_plugin_drain_playback(snd_pcm_t *handle);
 int snd_pcm_plugin_flush(snd_pcm_t *handle, int channel);
 int snd_pcm_plugin_pointer(snd_pcm_t *pcm, int channel, void **ptr, size_t *size);
 ssize_t snd_pcm_plugin_write(snd_pcm_t *handle, const void *buffer, size_t size);
@@ -355,8 +364,7 @@ typedef struct snd_pcm_loopback_callbacks {
 	void (*data) (void *private_data, char *buffer, size_t count);
 	void (*position_change) (void *private_data, unsigned int pos);
 	void (*format_change) (void *private_data, snd_pcm_format_t *format);
-	void (*silence) (void *private_data, size_t count);
-	void *reserved[31];		/* reserved for the future use - must be NULL!!! */
+	char *reserved[32];		/* reserved for the future use - must be NULL!!! */
 } snd_pcm_loopback_callbacks_t;
 
 int snd_pcm_loopback_open(snd_pcm_loopback_t **handle, int card, int device, int subdev, int mode);
@@ -493,10 +501,6 @@ int snd_seq_close(snd_seq_t *handle);
 int snd_seq_file_descriptor(snd_seq_t *handle);
 int snd_seq_block_mode(snd_seq_t *handle, int enable);
 int snd_seq_client_id(snd_seq_t *handle);
-int snd_seq_output_buffer_size(snd_seq_t *handle);
-int snd_seq_input_buffer_size(snd_seq_t *handle);
-int snd_seq_resize_output_buffer(snd_seq_t *handle, int size);
-int snd_seq_resize_input_buffer(snd_seq_t *handle, int size);
 int snd_seq_system_info(snd_seq_t *handle, snd_seq_system_info_t *info);
 int snd_seq_get_client_info(snd_seq_t *handle, snd_seq_client_info_t *info);
 int snd_seq_get_any_client_info(snd_seq_t *handle, int client, snd_seq_client_info_t *info);
@@ -539,9 +543,6 @@ snd_seq_event_t *snd_seq_create_event(void);
 int snd_seq_free_event(snd_seq_event_t *ev);
 int snd_seq_event_length(snd_seq_event_t *ev);
 int snd_seq_event_output(snd_seq_t *handle, snd_seq_event_t *ev);
-int snd_seq_event_output(snd_seq_t *handle, snd_seq_event_t *ev);
-int snd_seq_event_output_buffer(snd_seq_t *handle, snd_seq_event_t *ev);
-int snd_seq_event_output_direct(snd_seq_t *handle, snd_seq_event_t *ev);
 int snd_seq_event_input(snd_seq_t *handle, snd_seq_event_t **ev);
 int snd_seq_event_input_pending(snd_seq_t *seq, int fetch_sequencer);
 int snd_seq_event_input_selective(snd_seq_t *seq, snd_seq_event_t **ev, int type, int blocking);
@@ -599,13 +600,11 @@ void snd_seq_ev_schedule_real(snd_seq_event_t *ev, int q, int relative,
 /* set event priority (optional) */
 void snd_seq_ev_set_priority(snd_seq_event_t *ev, int high_prior);
 
-/* set event data type - following three macros are exclusive */
+/* set event data type - following two macros are exclusive */
   /* fixed size event */
 void snd_seq_ev_set_fixed(snd_seq_event_t *ev);
   /* variable size event */
 void snd_seq_ev_set_variable(snd_seq_event_t *ev, int len, void *ptr);
-  /* variable size event - user memory space */
-void snd_seq_ev_set_varusr(snd_seq_event_t *ev, int len, void *ptr);
 
 /* set queue control event data */
 /* destination is overwritten to Timer port (0:0) */
